summaryrefslogtreecommitdiffstats
path: root/sys/sys/_task.h
diff options
context:
space:
mode:
authorscottl <scottl@FreeBSD.org>2016-05-18 04:35:58 +0000
committerscottl <scottl@FreeBSD.org>2016-05-18 04:35:58 +0000
commit596f2a146d0b80c29929db3873e8d0f95be58796 (patch)
treec4ee95073f62d2e14fe35a639e6ee91bf1583c2f /sys/sys/_task.h
parentdc27d2be742522708e9a3be6ede0a3dddb3ed245 (diff)
downloadFreeBSD-src-596f2a146d0b80c29929db3873e8d0f95be58796.zip
FreeBSD-src-596f2a146d0b80c29929db3873e8d0f95be58796.tar.gz
Import the 'iflib' API library for network drivers. From the author:
"iflib is a library to eliminate the need for frequently duplicated device independent logic propagated (poorly) across many network drivers." Participation is purely optional. The IFLIB kernel config option is provided for drivers that want to transition between legacy and iflib modes of operation. ixl and ixgbe driver conversions will be committed shortly. We hope to see participation from the Broadcom and maybe Chelsio drivers in the near future. Submitted by: mmacy@nextbsd.org Reviewed by: gallatin Differential Revision: D5211
Diffstat (limited to 'sys/sys/_task.h')
-rw-r--r--sys/sys/_task.h13
1 files changed, 12 insertions, 1 deletions
diff --git a/sys/sys/_task.h b/sys/sys/_task.h
index 11fd1bc..4cfa171 100644
--- a/sys/sys/_task.h
+++ b/sys/sys/_task.h
@@ -45,10 +45,21 @@ typedef void task_fn_t(void *context, int pending);
struct task {
STAILQ_ENTRY(task) ta_link; /* (q) link for queue */
- u_short ta_pending; /* (q) count times queued */
+ uint8_t ta_pending; /* (q) count times queued */
+ uint8_t ta_flags; /* (q) flags */
u_short ta_priority; /* (c) Priority */
task_fn_t *ta_func; /* (c) task handler */
void *ta_context; /* (c) argument for handler */
};
+struct grouptask {
+ struct task gt_task;
+ void *gt_taskqueue;
+ LIST_ENTRY(grouptask) gt_list;
+ void *gt_uniq;
+ char *gt_name;
+ int16_t gt_irq;
+ int16_t gt_cpu;
+};
+
#endif /* !_SYS__TASK_H_ */
OpenPOWER on IntegriCloud